searchData={"items":[{"type":"module","title":"ReqIMDSv2","doc":"Provides a way to automatically authenticate Req requests with the Instance Metadata Service on\nan Amazon AWS EC2 instance.\n\nIt does this by making a request to IMDSv2 to get a token before the main request, then attaches that token\nto the request.\n\nThe EC2 docs specify that it's perfectly fine to request a new token for each request, but if you're making a\nlot in a row, it's possible to extract the token from the response and reuse it for subsequent requests. See\n`get_metadata_token/1` for more info.","ref":"ReqIMDSv2.html"},{"type":"module","title":"Examples - ReqIMDSv2","doc":"{:ok, response} =\n      Req.new(url: \"http://169.254.169.254/latest/meta-data/instance-id\")\n      |> ReqIMDSv2.attach()\n      |> Req.get()\n    {:ok, %Req.Response{body: \"i-1234567890abcdef0\", ...}\n\nIf you use a different host for IMDS data, such as for tests, the token will be fetched from that same URL:\n\n    iex> req = Req.new(url: \"http://localhost:4000/latest/meta-data/instance-id\")\n    iex> req = ReqIMDSv2.attach(req)\n    iex> {:ok, resp} = Req.get(req)\n    # ReqIMDSv2 will make a request to http://localhost:4000/latest/api/token to get the token.\n    iex> resp.body\n    \"i-1234567890abcdef0\"\n\nYou can extract the token from the response and reuse it for subsequent requests:\n\n    iex> req = Req.new(url: \"http://169.254.169.254/latest/meta-data/instance-id\")\n    iex> req = ReqIMDSv2.attach(req)\n    iex> {:ok, resp} = Req.get(req)\n    iex> token = ReqIMDSv2.get_metadata_token(resp)\n    iex> req = Req.new(url: \"http://169.254.169.254/latest/meta-data/hostname\")\n    ...> |> ReqIMDSv2.attach(metadata_token: token)\n    iex> Req.get!(req).body\n    \"ip-10-0-1-1.us-west-1.compute.internal\"\n\nSee `attach/2` for options.","ref":"ReqIMDSv2.html#module-examples"},{"type":"function","title":"ReqIMDSv2.attach/2","doc":"Attaches the IMDSv2 authentication steps to the request.\n\nOnce attached to a Req.Request, an extra request to get a IMDSv2 token will be made just prior to the original\nrequest is made. The token will be attached to the request as a header, and also attached to the response so it\ncan be extracted and reused for subsequent requests.\n\nThe request for the token will use the same scheme, host and port to connect to for the token as the original request.","ref":"ReqIMDSv2.html#attach/2"},{"type":"function","title":"Options - ReqIMDSv2.attach/2","doc":"* `:metadata_token` - A token to use for authentication. If not provided, a new token will be fetched from the\n    IMDSv2 service. See `get_metadata_token/1` for more info on extracting a token from a response.\n* `:metadata_token_ttl_seconds` - The TTL for the token. Defaults to the max allowed of 21600 (6 hours).\n* `:fallback_to_imdsv1` - If true, will fall back to IMDSv1 if IMDSv2 is not available, otherwise the request will\n    return an error. Defaults to false.","ref":"ReqIMDSv2.html#attach/2-options"},{"type":"function","title":"ReqIMDSv2.get_metadata_token/1","doc":"Extracts the metadata token from a response.\n\nThis can be used to reuse the token for subsequent requests. Returns `nil` if the token is not present, such as if\nthe token request failed and the request fell back to IMDSv1.","ref":"ReqIMDSv2.html#get_metadata_token/1"},{"type":"function","title":"Example - ReqIMDSv2.get_metadata_token/1","doc":"req =\n        Req.new(url: \"http://169.254.169.254/latest/meta-data/instance-id\")\n        |> ReqIMDSv2.attach(req)\n      {:ok, resp} = Req.get(req)\n      token = ReqIMDSv2.get_metadata_token(resp)","ref":"ReqIMDSv2.html#get_metadata_token/1-example"},{"type":"extras","title":"ReqIMDSv2","doc":"# ReqIMDSv2\n\nProvides a way to automatically authenticate Req requests with the Instance Metadata Service on\nan Amazon AWS EC2 instance.\n\nIt does this by making a request to IMDSv2 to get a token before the main request, then attaches that token\nto the request.","ref":"readme.html"},{"type":"extras","title":"Features - ReqIMDSv2","doc":"- Integrates easily with [Req](https://hexdocs.pm/req).\n- Handles the extra step of fetching and using a metadata token from IMDSv2.\n- Fetches the token from the same host as the original request.\n- Supports extracting the metadata token for re-use on subsequent requests.\n- Can enable `:fallback_to_imdsv1` if desired, in the case that IMDSv2 fails. (highly unlikely.)","ref":"readme.html#features"},{"type":"extras","title":"Installation - ReqIMDSv2","doc":"The package can be installed from [hex.pm](https://hex.pm/packages/req_imdsv2) by adding `req_imdsv2` to\nyour list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:req, \"~> 0.4.0\"},\n    {:req_imdsv2, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Documentation - ReqIMDSv2","doc":"Documentation is available from [hexdocs.pm](https://hexdocs.pm/req_imdsv2).","ref":"readme.html#documentation"},{"type":"extras","title":"Usage - ReqIMDSv2","doc":"This will work on an instance that has IMDSv2 required, and will not answer to IMDSv1 requests.\n\n```elixir\nReq.new(url: \"http://169.254.169.254/latest/meta-data/instance-id\")\n|> ReqIMDSv2.attach()\n|> Req.get!().body\n\"i-1234567890abcdef0\"\n```\n\nSee the `ReqIMDSv2` module for more information and examples.","ref":"readme.html#usage"}],"content_type":"text/markdown"}